@@ -242,7 +242,7 @@ DBD::Ingres - DBI driver for Ingres database systems
     	my $ti = [
     	    {   TYPE_NAME       => 0,
                 DATA_TYPE       => 1,
-                PRECISION       => 2,
+		COLUMN_SIZE	=> 2,
                 LITERAL_PREFIX  => 3,
                 LITERAL_SUFFIX  => 4,
                 CREATE_PARAMS   => 5,
@@ -250,44 +250,40 @@ DBD::Ingres - DBI driver for Ingres database systems
                 CASE_SENSITIVE  => 7,
                 SEARCHABLE      => 8,
                 UNSIGNED_ATTRIBUTE=> 9,
-                MONEY           => 10,
-                AUTO_INCREMENT  => 11,
+		FIXED_PREC_SCALE=> 10,
+		AUTO_UNIQUE_VALUE=> 11,
                 LOCAL_TYPE_NAME => 12,
                 MINIMUM_SCALE   => 13,
                 MAXIMUM_SCALE   => 14,
-		# additional and renamed keys:
-		COLUMN_SIZE	=> 2,
-		FIXED_PREC_SCALE=> 10,
-		AUTO_UNIQUE_VALUE=> 11,
 		SQL_DATA_TYPE	=> 15,
 		SQL_DATETIME_SUB=> 16,
 		NUM_PREC_RADIX	=> 17,
 		INTERVAL_PRECISIO=> 18,
     	    },
     	    [ 'SMALLINT',     DBI::SQL_SMALLINT,
-	      undef, "","",  undef, 1, 0, 2, 0, 0, 0, undef, 0, 0 ],
+	      undef, "","",  undef, 1, 0, 2, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'INTEGER',      DBI::SQL_INTEGER,
-	      undef, "","", "size=1,2,4", 1, 0, 2, 0, 0 ,0 ,undef ,0 ,0 ],
+	      undef, "","", "size=1,2,4", 1, 0, 2, 0, 0 ,0 ,undef ,0 ,0, undef, undef, undef, undef ],
     	    [ 'MONEY',        DBI::SQL_DECIMAL,
-	      undef, "","",  undef, 1, 0, 2, 0, 1, 0, undef, 0, 0 ],
+	      undef, "","",  undef, 1, 0, 2, 0, 1, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'FLOAT',        DBI::SQL_DOUBLE,
-	      undef, "","", "size=4,8", 1, 0, 2, 0, 0, 0, undef, 0, 0 ],
+	      undef, "","", "size=4,8", 1, 0, 2, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'DATE',         DBI::SQL_DATE,   
-	      undef, "'","'", undef, 1, 0, 3, 0, 0, 0, undef, 0, 0 ],
+	      undef, "'","'", undef, 1, 0, 3, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'DECIMAL',      DBI::SQL_DECIMAL,
-	      undef, "","", "precision,scale", 1, 0, 2, 0, 0, 0, undef, 0, 0 ],
+	      undef, "","", "precision,scale", 1, 0, 2, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'VARCHAR',      DBI::SQL_VARCHAR,
-	      undef, "'","'", "max length", 1, 1, 3, 0, 0, 0, undef, 0, 0 ],
+	      undef, "'","'", "max length", 1, 1, 3, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'BYTE VARYING', DBI::SQL_VARBINARY,
-	      undef, "'","'", "max length", 1, 1, 3, 0, 0, 0, undef, 0, 0 ],
+	      undef, "'","'", "max length", 1, 1, 3, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'CHAR',         DBI::SQL_CHAR,   
-	      undef, "'","'", "length", 1, 1, 3, 0, 0, 0, undef, 0, 0 ],
+	      undef, "'","'", "length", 1, 1, 3, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'BYTE',         DBI::SQL_BINARY, 
-	      undef, "'","'", "length", 1, 1, 3, 0, 0, 0, undef, 0, 0 ],
+	      undef, "'","'", "length", 1, 1, 3, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'LONG VARCHAR', DBI::SQL_LONGVARCHAR, 
-	      undef, undef, undef, undef, 1, 1, 0, 0, 0, 0, undef, 0, 0 ],
+	      undef, undef, undef, undef, 1, 1, 0, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	    [ 'LONG BYTE', DBI::SQL_LONGVARBINARY, 
-	      undef, undef, undef, undef, 1, 1, 0, 0, 0, 0, undef, 0, 0 ],
+	      undef, undef, undef, undef, 1, 1, 0, 0, 0, 0, undef, 0, 0, undef, undef, undef, undef ],
     	];
     	return $ti;
     }
